Dataset with images of 2 resolutions (see config name for information on the
resolution). It is used for density estimation and generative modeling
experiments.

For resized ImageNet for supervised learning
([link](https://patrykchrabaszcz.github.io/Imagenet32/)) see `imagenet_resized`.
